@@ -23,10 +23,12 @@ from rally.task import validation
 """Scenarios for Ceilometer Queries API."""
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerQueries.create_and_query_alarms")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerQueries.create_and_query_alarms",
+                    platform="openstack")
 class CeilometerQueriesCreateAndQueryAlarms(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, filter=None, orderby=None,
@@ -50,10 +52,12 @@ class CeilometerQueriesCreateAndQueryAlarms(ceiloutils.CeilometerScenario):
         self._query_alarms(filter, orderby, limit)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerQueries.create_and_query_alarm_history")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerQueries.create_and_query_alarm_history",
+                    platform="openstack")
 class CeilometerQueriesCreateAndQueryAlarmHistory(ceiloutils
                                                   .CeilometerScenario):
 
@@ -75,10 +79,12 @@ class CeilometerQueriesCreateAndQueryAlarmHistory(ceiloutils
         self._query_alarm_history(alarm_filter, orderby, limit)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerQueries.create_and_query_samples")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerQueries.create_and_query_samples",
+                    platform="openstack")
 class CeilometerQueriesCreateAndQuerySamples(ceiloutils.CeilometerScenario):
 
     def run(self, counter_name, counter_type, counter_unit, counter_volume,
