@@ -26,7 +26,6 @@ from rally import exceptions
 from rally.task import context
 from rally.task import engine
 from rally.task import scenario
-from tests.unit import fakes
 from tests.unit import test
 
 
@@ -313,17 +312,17 @@ class TaskEngineTestCase(test.TestCase):
                          "Subtask configuration:\n<JSON>\n\n"
                          "Reason(s):\n trigger_error", e.format_message())
 
-    @mock.patch("rally.task.engine.context.Context")
+    @mock.patch("rally.task.engine.context.ContextManager.cleanup")
+    @mock.patch("rally.task.engine.context.ContextManager.setup")
     @mock.patch("rally.task.engine.TaskConfig")
-    @mock.patch("rally.task.engine.objects.Deployment.get",
-                return_value="FakeDeployment")
-    def test__validate_config_semantic(
-            self, mock_deployment_get,
-            mock_task_config, mock_context):
-        admin = fakes.fake_credential(foo="admin")
-        users = [fakes.fake_credential(bar="user1")]
-        deployment = fakes.FakeDeployment(
-            uuid="deployment_uuid", admin=admin, users=users)
+    def test__validate_config_semantic(self, mock_task_config,
+                                       mock_context_manager_setup,
+                                       mock_context_manager_cleanup):
+        env = mock.MagicMock(uuid="env_uuid")
+        env.check_health.return_value = {
+            "foo": {"available": True, "message": ""},
+            "bar": {"available": True, "message": ""}
+        }
 
         @scenario.configure("SomeScen.scenario")
         class SomeScen(scenario.Scenario):
@@ -344,41 +343,47 @@ class TaskEngineTestCase(test.TestCase):
 
         mock_task_instance.subtasks = [subtask1, subtask2]
         fake_task = mock.MagicMock()
-        eng = engine.TaskEngine(mock_task_instance, fake_task, deployment)
+        eng = engine.TaskEngine(mock_task_instance, fake_task, env)
 
         eng._validate_config_semantic(mock_task_instance)
 
+        env.check_health.return_value = {
+            "foo": {"available": True, "message": ""},
+            "bar": {"available": False, "message": "", "traceback": "AAAA"}
+        }
+        self.assertRaises(exceptions.ValidationError,
+                          eng._validate_config_semantic,
+                          mock_task_instance)
+
     @mock.patch("rally.task.engine.TaskConfig")
     @mock.patch("rally.task.engine.TaskEngine._validate_workload")
     def test__validate_config_platforms(
             self, mock__validate_workload, mock_task_config):
 
-        class FakeDeployment(object):
-            def __init__(self, credentials):
-                self._creds = credentials
-                self.get_all_credentials = mock.Mock()
-                self.get_all_credentials.return_value = self._creds
-
-        foo_cred1 = {"admin": "admin", "users": ["user1"]}
-        foo_cred2 = {"admin": "admin", "users": ["user1"]}
-        deployment = FakeDeployment({"foo": [foo_cred1, foo_cred2]})
+        foo_cred = {"admin": "admin", "users": ["user1"]}
+        env = mock.MagicMock(data={
+            "platforms": {
+                "foo": {
+                    "platform_name": "foo", "platform_data": foo_cred
+                }
+            }
+        })
 
         workload1 = "workload1"
         workload2 = "workload2"
         subtasks = [{"workloads": [workload1]},
                     {"workloads": [workload2]}]
         config = mock.Mock(subtasks=subtasks)
-        eng = engine.TaskEngine({}, mock.MagicMock(), deployment)
+        eng = engine.TaskEngine({}, mock.MagicMock(), env)
 
         eng._validate_config_platforms(config)
 
         self.assertEqual(
             [mock.call(w, vtype="platform",
-                       vcontext={"platforms": {"foo": foo_cred1},
+                       vcontext={"platforms": {"foo": foo_cred},
                                  "task": eng.task})
              for w in (workload1, workload2)],
             mock__validate_workload.call_args_list)
-        deployment.get_all_credentials.assert_called_once_with()
 
     @mock.patch("rally.common.objects.Task.get_status")
     @mock.patch("rally.task.engine.TaskConfig")
@@ -427,18 +432,16 @@ class TaskEngineTestCase(test.TestCase):
         mock_task_instance.subtasks = [{
             "title": "foo",
             "description": "Do not launch it!!",
-            "context": {},
+            "contexts": {},
             "workloads": [
                 self._make_workload(name="a.task", description="foo",
                                     contexts={"context_a": {"a": 1}}),
                 self._make_workload(name="a.task", description="foo",
                                     contexts={"context_a": {"b": 2}},
                                     position=2)]}]
-
-        deployment = fakes.FakeDeployment(
-            uuid="deployment_uuid", admin={"foo": "admin"})
         eng = engine.TaskEngine(mock_task_instance, mock.MagicMock(),
-                                deployment)
+                                mock.MagicMock())
+
         eng.run()
 
         self.assertEqual(2, mock_log.exception.call_count)
@@ -471,9 +474,7 @@ class TaskEngineTestCase(test.TestCase):
         fake_runner = mock.MagicMock()
         fake_runner_cls.return_value = fake_runner
         mock_scenario_runner.get.return_value = fake_runner_cls
-        deployment = fakes.FakeDeployment(
-            uuid="deployment_uuid", admin={"foo": "admin"})
-        eng = engine.TaskEngine(config, task, deployment)
+        eng = engine.TaskEngine(config, task, mock.MagicMock())
 
         eng.run()
 
@@ -575,13 +576,17 @@ class TaskEngineTestCase(test.TestCase):
         name = "test_ctx.test"
         context_config = {"test1": 1, "test2": 2}
 
-        eng = engine.TaskEngine({}, task, mock.MagicMock())
+        env = mock.MagicMock()
+        eng = engine.TaskEngine({}, task, env)
+
         result = eng._prepare_context(context_config, name, "foo_uuid")
+
         expected_result = {
             "task": task,
             "owner_id": "foo_uuid",
             "scenario_name": name,
-            "config": {"test1@testing": 1, "test2@testing": 2}
+            "config": {"test1@testing": 1, "test2@testing": 2},
+            "env": env.data
         }
         self.assertEqual(expected_result, result)
 
@@ -610,8 +615,12 @@ class ResultConsumerTestCase(test.TestCase):
 
         runner.result_queue = collections.deque(results)
         runner.event_queue = collections.deque()
-        with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                   runner, False) as consumer_obj:
+        ctx_manager = mock.MagicMock()
+
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   abort_on_sla_failure=False,
+                                   ctx_manager=ctx_manager) as consumer_obj:
             pass
 
         mock_sla_instance.add_iteration.assert_has_calls([
@@ -646,14 +655,19 @@ class ResultConsumerTestCase(test.TestCase):
         results = []
         runner.result_queue = collections.deque(results)
         runner.event_queue = collections.deque()
-        with engine.ResultConsumer(
-                workload_cfg, task, subtask, workload, runner, False):
+        ctx_manager = mock.MagicMock()
+
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   abort_on_sla_failure=False,
+                                   ctx_manager=ctx_manager):
             pass
 
         self.assertFalse(workload.add_workload_data.called)
         workload.set_results.assert_called_once_with(
             full_duration=1, sla_results=mock_sla_results, load_duration=0,
-            start_time=None)
+            start_time=None,
+            contexts_results=ctx_manager.contexts_results())
 
     @mock.patch("rally.common.objects.Task.get_status")
     @mock.patch("rally.task.engine.ResultConsumer.wait_and_abort")
@@ -674,9 +688,12 @@ class ResultConsumerTestCase(test.TestCase):
         runner.result_queue = collections.deque(
             [[{"duration": 1, "timestamp": 1},
               {"duration": 2, "timestamp": 2}]] * 4)
+        ctx_manager = mock.MagicMock()
 
-        with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                   runner, True):
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   abort_on_sla_failure=True,
+                                   ctx_manager=ctx_manager):
             pass
 
         self.assertTrue(runner.abort.called)
@@ -705,9 +722,12 @@ class ResultConsumerTestCase(test.TestCase):
         workload_cfg = {"fake": 2, "hooks": []}
 
         mock_hook_executor_instance = mock_hook_executor.return_value
+        ctx_manager = mock.MagicMock()
 
-        with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                   runner, True):
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   abort_on_sla_failure=True,
+                                   ctx_manager=ctx_manager):
             pass
 
         mock_sla_checker.assert_called_once_with(workload_cfg)
@@ -733,9 +753,12 @@ class ResultConsumerTestCase(test.TestCase):
         runner.result_queue = collections.deque(
             [[{"duration": 1, "timestamp": 4}]] * 4)
         runner.event_queue = collections.deque()
+        ctx_manager = mock.MagicMock()
 
-        with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                   runner, False):
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   ctx_manager=ctx_manager,
+                                   abort_on_sla_failure=False):
             pass
 
         self.assertEqual(0, runner.abort.call_count)
@@ -756,13 +779,18 @@ class ResultConsumerTestCase(test.TestCase):
         runner = mock.MagicMock()
         runner.result_queue = collections.deque([1])
         runner.event_queue = collections.deque()
+        ctx_manager = mock.MagicMock()
         exc = MyException()
         try:
-            with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                       runner, False):
+            with engine.ResultConsumer(workload_cfg, task=task,
+                                       subtask=subtask, workload=workload,
+                                       runner=runner, ctx_manager=ctx_manager,
+                                       abort_on_sla_failure=False):
                 raise exc
         except MyException:
             pass
+        else:
+            self.fail("ResultConsumer should re-raise the exception.")
 
         mock_sla_instance.set_unexpected_failure.assert_has_calls(
             [mock.call(exc)])
@@ -796,8 +824,12 @@ class ResultConsumerTestCase(test.TestCase):
 
         runner.result_queue = collections.deque(results)
         runner.event_queue = collections.deque()
-        with engine.ResultConsumer(workload_cfg, task, subtask, workload,
-                                   runner, False) as consumer_obj:
+        ctx_manager = mock.MagicMock()
+
+        with engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                   workload=workload, runner=runner,
+                                   abort_on_sla_failure=False,
+                                   ctx_manager=ctx_manager) as consumer_obj:
             pass
 
         mock_sla_instance.add_iteration.assert_has_calls([
@@ -850,8 +882,10 @@ class ResultConsumerTestCase(test.TestCase):
         runner.result_queue = collections.deque()
         runner.event_queue = collections.deque(events)
 
-        consumer_obj = engine.ResultConsumer(workload_cfg, task, subtask,
-                                             workload, runner, False)
+        ctx_manager = mock.MagicMock()
+        consumer_obj = engine.ResultConsumer(
+            workload_cfg, task=task, subtask=subtask, workload=workload,
+            runner=runner, abort_on_sla_failure=False, ctx_manager=ctx_manager)
         stop_event = threading.Event()
 
         def set_stop_event(event_type, value):
@@ -875,7 +909,8 @@ class ResultConsumerTestCase(test.TestCase):
             load_duration=0,
             sla_results=mock_sla_results,
             hooks_results=mock_hook_results,
-            start_time=None)
+            start_time=None,
+            contexts_results=ctx_manager.contexts_results())
 
     @mock.patch("rally.task.engine.threading.Thread")
     @mock.patch("rally.task.engine.threading.Event")
@@ -886,7 +921,7 @@ class ResultConsumerTestCase(test.TestCase):
             self, mock_sleep, mock_task_engine__prepare_context,
             mock_task_get_status, mock_event, mock_thread):
         runner = mock.MagicMock()
-        key = mock.MagicMock()
+        workload_cfg = mock.MagicMock()
         task = mock.MagicMock()
         subtask = mock.Mock(spec=objects.Subtask)
         workload = mock.Mock(spec=objects.Workload)
@@ -896,8 +931,12 @@ class ResultConsumerTestCase(test.TestCase):
         mock_is_done = mock.MagicMock()
         mock_event.return_value = mock_is_done
         mock_is_done.isSet.return_value = False
+        ctx_manager = mock.MagicMock()
 
-        res = engine.ResultConsumer(key, task, subtask, workload, runner, True)
+        res = engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                    workload=workload, runner=runner,
+                                    abort_on_sla_failure=True,
+                                    ctx_manager=ctx_manager)
         res.wait_and_abort()
 
         runner.abort.assert_called_with()
@@ -913,17 +952,21 @@ class ResultConsumerTestCase(test.TestCase):
             self, mock_sleep, mock_task_engine__prepare_context,
             mock_task_get_status, mock_event, mock_thread):
         runner = mock.MagicMock()
-        key = mock.MagicMock()
+        workload_cfg = mock.MagicMock()
         task = mock.MagicMock()
         subtask = mock.Mock(spec=objects.Subtask)
         workload = mock.Mock(spec=objects.Workload)
         mock_task_get_status.return_value = consts.TaskStatus.RUNNING
         mock_is_done = mock.MagicMock()
         mock_event.return_value = mock_is_done
+        ctx_manager = mock.MagicMock()
 
         mock_is_done.isSet.side_effect = [False, False, False, False, True]
 
-        res = engine.ResultConsumer(key, task, subtask, workload, runner, True)
+        res = engine.ResultConsumer(workload_cfg, task=task, subtask=subtask,
+                                    workload=workload, runner=runner,
+                                    abort_on_sla_failure=True,
+                                    ctx_manager=ctx_manager)
         res.wait_and_abort()
 
         # check method don't abort runner if task is not aborted
